==> KinTPV_8_236_Intl_serveur.zip: install/js/install.js <==
function GetHttpRequest()
{
	var xhr=null;
  if(window.XMLHttpRequest) 
  xhr = new XMLHttpRequest();
  else if(window.ActiveXObject){ 
    try {
      xhr = new ActiveXObject("Msxml2.XMLHTTP");
    } catch (e) {
      try {
        xhr = new ActiveXObject("Microsoft.XMLHTTP");
      } catch (e1) {
        xhr = null;
      }
    }
  }
  
  return xhr;
}

function PreparePostData(xhr, url, donnees)
{
  xhr.open("POST",url,true);
	xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
	xhr.setRequestHeader("Content-length", donnees.length);
	xhr.setRequestHeader("Connection", "close");
}

function GetXMLValue(xml, nom_balise)
{
  var retour = '';
  var balise = xml.getElementsByTagName(nom_balise);
  if(balise && balise.length>0 && balise[0].firstChild)
    retour = balise[0].textContent;//firstChild.data;
  
  return retour;
}

function install(step)
{
	requete_install(step);
}

function check_config()
{
	var formulaire = document.form_params;
	var datas = "host="+formulaire.host.value;
	datas+= "&user="+formulaire.user.value;
	datas+= "&password="+formulaire.password.value;
	datas+= "&db_prefix="+formulaire.prefix.value;
	datas+= "&db_name="+formulaire.db_name.value;
	
	requete_install(1, datas);
}

function save_user()
{
	var formulaire = document.form_user;
	var datas = "Email="+formulaire.Email.value;
	datas+= "&MotPasse="+formulaire.MotPasse.value;
	
	requete_install(4, datas);
}

function requete_install(step, datas)
{
	var xhr = GetHttpRequest();
	var ts = new Date(); 
	var donnees = "step="+step;
	if(datas)donnees+= "&"+datas;
	
	PreparePostData(xhr, "install.php?ts="+String(ts.getTime()), donnees);
	
	xhr.onreadystatechange=function() 
  {
    if(xhr.readyState==4)
    {
    	if(xhr.responseXML) 
    	{
	    	// il faut afficher l'écran correspondant à la réponse
	    	var next_step = GetXMLValue(xhr.responseXML, 'NEXT_STEP');
	    	var error = GetXMLValue(xhr.responseXML, 'ERROR');
	    	
	    	affiche_ecran(parseInt(next_step), error);
	    }
	    else
	    {
	    	alert(xhr.responseText);
	    }
	    $("input").prop('disabled', false);
    }
  }
  $("input").prop('disabled', true);
  xhr.send(donnees);
}

function affiche_ecran(step, error)
{
	$(".step_install").addClass("hidden");
	var zone = '';
	switch(step)
	{
		case -1:
			zone = "stepFatalError";
			break;
		case 1:
			zone = "step1";
			break;
		case 4:
			zone = "step4";
			break;
		case 100:
			zone = "step100";
			break;
		default:
			zone = "step_install";
			break;
	}
	$("#"+zone).removeClass("hidden");
	AfficheErreur(zone, error);
}

function AfficheErreur(zone, code)
{
	var message = '';
	if(code != '')
	{
		switch(code)
		{
			case 'DB CONFIG FILE ERROR':
				message = "Impossible d'écrire le fichier de configuration de la base de données";
				break;
			case 'DB CONNECTION ERROR':
				message = "Erreur durant la connexion à la base de données. Veuillez vérifier les paramètres.";
				break;
			case 'USER CREATION ERROR':
				message = "Impossible de créer l'utilisateur. Veuillez vérifier les paramètres.";
				break;
			case 'PHP VERSION NOT SUPPORTED':
				message = "La version de PHP de votre hébergement n'est pas compatible avec ce service. Les versions supportées sont PHP 5.6 à PHP 7.0";
				break;
			default:
				message = "Erreur critique : "+code;
		}
		
	}
	
	$("#"+zone+" .alert").html(message);
	
	if(message != "")
		$("#"+zone+" .alert").show();
	else
		$("#"+zone+" .alert").hide();
}

==> KinTPV_11_199_Intl_serveur.zip: install/js/install.js <==
function GetHttpRequest()
{
	var xhr=null;
  if(window.XMLHttpRequest)
  xhr = new XMLHttpRequest();
  else if(window.ActiveXObject){
    try {
      xhr = new ActiveXObject("Msxml2.XMLHTTP");
    } catch (e) {
      try {
        xhr = new ActiveXObject("Microsoft.XMLHTTP");
      } catch (e1) {
        xhr = null;
      }
    }
  }

  return xhr;
}

function PreparePostData(xhr, url, donnees)
{
  xhr.open("POST",url,true);
	xhr.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
	//xhr.setRequestHeader("Content-length", donnees.length);
	//xhr.setRequestHeader("Connection", "close");
}

function GetXMLValue(xml, nom_balise)
{
  var retour = '';
  var balise = xml.getElementsByTagName(nom_balise);
  if(balise && balise.length>0 && balise[0].firstChild)
    retour = balise[0].textContent;//firstChild.data;

  return retour;
}

function install(step)
{
	requete_install(step);
}

function check_config()
{
	var formulaire = document.form_params;
	var datas = "host="+formulaire.host.value;
	var password = formulaire.password.value;
	password = password.replace('\&', '%26');
	datas+= "&user="+formulaire.user.value;
	datas+= "&password="+password;
	datas+= "&db_prefix="+formulaire.prefix.value;
	datas+= "&db_name="+formulaire.db_name.value;

	requete_install(1, datas);
}

function save_user()
{
	var formulaire = document.form_user;
	var datas = "Email="+formulaire.Email.value;
	datas+= "&MotPasse="+formulaire.MotPasse.value;

	requete_install(4, datas);
}

function requete_install(step, datas)
{
	var xhr = GetHttpRequest();
	var ts = new Date();
	var donnees = "step="+step;
	if(datas)donnees+= "&"+datas;

	PreparePostData(xhr, "install.php?ts="+String(ts.getTime()), donnees);

	xhr.onreadystatechange=function()
  {
    if(xhr.readyState==4)
    {
    	if(xhr.responseXML)
    	{
	    	// il faut afficher l'écran correspondant à la réponse
	    	var next_step = GetXMLValue(xhr.responseXML, 'NEXT_STEP');
				var error = GetXMLValue(xhr.responseXML, 'ERROR');

	    	affiche_ecran(parseInt(next_step), error);
	    }
	    else
	    {
	    	alert(xhr.responseText);
	    }
	    $("input").prop('disabled', false);
    }
  }
  $("input").prop('disabled', true);
  xhr.send(donnees);
}

function affiche_ecran(step, error)
{
	$(".step_install").addClass("hidden");
	var zone = '';
	switch(step)
	{
		case -1:
			zone = "stepFatalError";
			break;
		case 1:
			zone = "step1";
			break;
		case 4:
			zone = "step4";
			break;
		case 100:
			zone = "step100";
			break;
		default:
			zone = "step_install";
			break;
	}
	$("#"+zone).removeClass("hidden");
	AfficheErreur(zone, error);
}

function AfficheErreur(zone, code)
{
	var message = '';
	if(code != '')
	{
		switch(code)
		{
			case 'DB CONFIG FILE ERROR':
				message = "Impossible d'écrire le fichier de configuration de la base de données";
				break;
			case 'DB CONNECTION ERROR':
				message = "Erreur durant la connexion à la base de données. Veuillez vérifier les paramètres.";
				break;
			case 'USER CREATION ERROR':
				message = "Impossible de créer l'utilisateur. Veuillez vérifier les paramètres.";
				break;
			case 'PHP VERSION NOT SUPPORTED':
				message = "La version de PHP de votre hébergement n'est pas compatible avec ce service. Les versions supportées sont PHP 5.6 ou suppérieur.";

				break;
			default:
				message = "Erreur critique : "+code;
		}

	}

	$("#"+zone+" .alert").html(message);

	if(message != "")
		$("#"+zone+" .alert").show();
	else
		$("#"+zone+" .alert").hide();
}
